@@ -2,7 +2,7 @@
  * This program source code file is part of KiCad, a free EDA CAD application.
  *
  * Copyright (C) 1992-2011 Jean-Pierre Charras.
- * Copyright (C) 1992-2021 KiCad Developers, see change_log.txt for contributors.
+ * Copyright The KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -24,10 +24,11 @@
 
 #include <netlist_lexer.h>  // netlist_lexer is common to Eeschema and Pcbnew
 #include <string_utils.h>
-#include <nlohmann/json.hpp>
+#include <json_common.h>
 
 #include "pcb_netlist.h"
 #include "netlist_reader.h"
+#include "kicad_netlist_parser.h"
 
 using namespace NL_T;
 
@@ -183,7 +184,6 @@ void KICAD_NETLIST_PARSER::parseNet()
      *  (node (ref "U9") (pin "M6") (pin_function "reset")))
      */
 
-    COMPONENT* component = NULL;
     wxString   code;
     wxString   name;
     wxString   reference;
@@ -257,25 +257,18 @@ void KICAD_NETLIST_PARSER::parseNet()
                 }
             }
 
-            if( strtol( code.c_str(), NULL, 10 ) >= 1 )
+            // Don't assume component will be found; it might be "DNP" or "Exclude from board".
+            if( COMPONENT* component = m_netlist->GetComponentByReference( reference ) )
             {
-                if( name.IsEmpty() )      // Give a dummy net name like N-000009
-                    name = wxT("N-00000") + code;
-
-                component = m_netlist->GetComponentByReference( reference );
-
-                // Cannot happen if the netlist is valid.
-                if( component == NULL )
+                if( strtol( code.c_str(), nullptr, 10 ) >= 1 )
                 {
-                    wxString msg;
-                    msg.Printf( _( "Cannot find component with ref '%s' in netlist." ),
-                                reference );
-                    THROW_PARSE_ERROR( msg, m_lineReader->GetSource(), m_lineReader->Line(),
-                                       m_lineReader->LineNumber(), m_lineReader->Length() );
-                }
+                    if( name.IsEmpty() )      // Give a dummy net name like N-000009
+                        name = wxT("N-00000") + code;
 
-                component->AddNet( pin_number, name, pin_function, pin_type );
+                    component->AddNet( pin_number, name, pin_function, pin_type );
+                }
             }
+
             break;
 
         default:
@@ -288,13 +281,14 @@ void KICAD_NETLIST_PARSER::parseNet()
 
 void KICAD_NETLIST_PARSER::parseComponent()
 {
-   /* Parses a section like
+    /* Parses a section like
      * (comp (ref P1)
      *   (value DB25FEMALE)
      *   (footprint DB25FC)
      *   (libsource (lib conn) (part DB25))
      *   (property (name PINCOUNT) (value 25))
      *   (sheetpath (names /) (tstamps /))
+     *   (component_classes (class (name "CLASS")))
      *   (tstamp 68183921-93a5-49ac-91b0-49d05a0e1647))
      *
      * other fields (unused) are skipped
@@ -307,11 +301,13 @@ void KICAD_NETLIST_PARSER::parseComponent()
     wxString    value;
     wxString    library;
     wxString    name;
+    wxString    humanSheetPath;
     KIID_PATH   path;
 
     std::vector<KIID>            uuids;
     std::map<wxString, wxString> properties;
     nlohmann::ordered_map<wxString, wxString> fields;
+    std::unordered_set<wxString>              componentClasses;
 
     // The token comp was read, so the next data is (ref P1)
     while( (token = NextTok() ) != T_RIGHT )
@@ -404,8 +400,6 @@ void KICAD_NETLIST_PARSER::parseComponent()
             break;
 
         case T_fields:
-
-            // Read fields
             while( ( token = NextTok() ) != T_RIGHT )
             {
                 if( token == T_LEFT )
@@ -429,7 +423,7 @@ void KICAD_NETLIST_PARSER::parseComponent()
                         }
                         else if( token == T_STRING )
                         {
-                            fieldValue = CurText();
+                            fieldValue = From_UTF8( CurText() );
                         }
                     }
 
@@ -446,14 +440,24 @@ void KICAD_NETLIST_PARSER::parseComponent()
         case T_sheetpath:
             while( ( token = NextTok() ) != T_EOF )
             {
+                if( token == T_names )
+                {
+                    NeedSYMBOLorNUMBER();
+                    humanSheetPath = From_UTF8( CurText() );
+                    NeedRIGHT();
+                }
+
                 if( token == T_tstamps )
+                {
+                    NeedSYMBOLorNUMBER();
+                    path = KIID_PATH( From_UTF8( CurText() ) );
+                    NeedRIGHT();
                     break;
+                }
             }
 
-            NeedSYMBOLorNUMBER();
-            path = KIID_PATH( From_UTF8( CurText() ) );
-            NeedRIGHT();
             NeedRIGHT();
+
             break;
 
         case T_tstamps:
@@ -467,6 +471,22 @@ void KICAD_NETLIST_PARSER::parseComponent()
 
             break;
 
+        case T_component_classes:
+            while( ( token = NextTok() ) != T_RIGHT )
+            {
+                if( token != T_LEFT )
+                    Expecting( T_LEFT );
+
+                if( ( token = NextTok() ) != T_class )
+                    Expecting( T_class );
+
+                NeedSYMBOLorNUMBER();
+                componentClasses.insert( From_UTF8( CurText() ) );
+                NeedRIGHT();
+            }
+
+            break;
+
         default:
             // Skip not used data (i.e all other tokens)
             skipCurrent();
@@ -477,7 +497,7 @@ void KICAD_NETLIST_PARSER::parseComponent()
     if( !footprint.IsEmpty() && fpid.Parse( footprint, true ) >= 0 )
     {
         wxString error;
-        error.Printf( _( "Invalid footprint ID in\nfile: '%s'\nline: %d\noffset: %d" ),
+        error.Printf( _( "Invalid footprint ID in\nfile: '%s'\nline: %d\nofff: %d" ),
                       CurSource(), CurLineNumber(), CurOffset() );
 
         THROW_IO_ERROR( error );
@@ -488,6 +508,8 @@ void KICAD_NETLIST_PARSER::parseComponent()
     component->SetLibrary( library );
     component->SetProperties( properties );
     component->SetFields( fields );
+    component->SetHumanReadablePath( humanSheetPath );
+    component->SetComponentClassNames( componentClasses );
     m_netlist->AddComponent( component );
 }
 
